@@ -3,11 +3,12 @@
 ;; Copyright (C) 2020-2022  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>,
-;;         Damien Cassou <damien@cassou.me>
-;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
+;;         Damien Cassou <damien@cassou.me>,
+;;         Daniel Mendler <mail@daniel-mendler.de>
+;; Maintainer: TMR Development <~protesilaos/tmr@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/tmr
-;; Mailing list: https://lists.sr.ht/~protesilaos/tmr
-;; Version: 0.3.1
+;; Mailing-List: https://lists.sr.ht/~protesilaos/tmr
+;; Version: 0.4.0
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -38,7 +39,6 @@
 
 ;;; Code:
 (require 'tmr)
-(require 'tmr-sound)
 (require 'notifications)
 
 (defcustom tmr-notification-urgency 'normal
@@ -58,14 +58,16 @@ such notifications."
   "Dispatch a notification for TIMER.
 
 Read: (info \"(elisp) Desktop Notifications\") for details."
-  (let ((title "TMR May Ring (Emacs tmr package)")
-        (body (tmr--long-description-for-completed-timer timer)))
-    (notifications-notify
-     :title title
-     :body body
-     :app-name "GNU Emacs"
-     :urgency tmr-notification-urgency
-     :sound-file tmr-sound-file)))
+  (if (featurep 'dbusbind)
+      (let ((title "TMR May Ring (Emacs tmr package)")
+            (body (tmr--long-description-for-finished-timer timer)))
+        (notifications-notify
+         :title title
+         :body body
+         :app-name "GNU Emacs"
+         :urgency tmr-notification-urgency
+         :sound-file tmr-sound-file))
+    (warn "Emacs has no DBUS support, TMR notifications unavailable")))
 
 (provide 'tmr-notification)
 ;;; tmr-notification.el ends here
